import { copyToClipboard, useQuasar } from 'quasar'

const $q = useQuasar()
/**
 * 复制文本
 * @param string
 */
function copy(string: string) {
  copyToClipboard(string)
    .then(() => {
      // success!
      $q.notify({
        message: '复制成功',
        color: 'positive',
        position: 'top'
      })
    })
    .catch(() => {
      // fail
      $q.notify({
        message: '复制失败',
        color: 'negative'
      })
    })
}
/**
 *根据延迟计算颜色
 * @param bili 数值 延迟单位ms
 * @returns
 */
const getColorByBaiFenBi = (bili: number) => {
  //var 百分之一 = (单色值范围) / 50;  单颜色的变化范围只在50%之内
  const one = (255 + 255) / 100;
  let r = 0;
  let g = 0;
  let b = 0;

  if (bili < 50) {
    // 比例小于50的时候红色是越来越多的,直到红色为255时(红+绿)变为黄色.
    r = one * bili;
    g = 255;
  }
  if (bili >= 50) {
    // 比例大于50的时候绿色是越来越少的,直到0 变为纯红
    g = 255 - ((bili - 50) * one);
    r = 255;
  }
  r = Math.round(r);// 取整
  g = Math.round(g);// 取整
  b = Math.round(b);// 取整

  return 'rgb(' + r + ',' + g + ',' + b + ')';

}
/**
 * 根据延迟计算颜色 就三种颜色
 * @param bili
 * @returns
 */
function signal_style(bili: number) {
  let tmp = ''
  if (bili >= 0 && bili <= 700) {
    tmp = 'green'
  } else if (bili > 700 && bili < 1400) {
    tmp = '#FF9800'
  } else {
    tmp = 'red'
  }
  return tmp
}

export { copy, getColorByBaiFenBi, signal_style }
